@@ -678,9 +678,6 @@ QVariant DeviceModel::data(const QModelIndex &index, int role) const
             if (displayName.isEmpty())
                 displayName = device->getAddress();
 
-            if (!device->isPaired())
-                displayName.append("…");
-
             ret = displayName;
             break;
 
